;; Copyright (C) 2001 Jason Henriksen <jason@h3c.com>
;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>

;; This file is part of sawmill.

;; sawmill is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; sawmill is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with sawmill; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;; This theme was produced by Jason Henriksen.  In accordance with the GPL
;; and it's use of GPL'ed source, this file is also released under the
;; GPL.  The goal of this theme is to provide a powerful window manager
;; interface coupled with the flexibility of image re-coloring.  It is
;; based largely on a mixture of the BrushedMetalII, Crux and Simple 
;; themes.  
;;
;; Building this theme would have been impossible without the resources at:
;;
;; http://fox.mit.edu/doc/sawmill/sawmill_toc.html
;; http://ringer.cs.utsa.edu/research/AI/cltl/common-lisp-tutorial.html
;;
;; All graphics named 'part#*' are taken from BrushedMetalII

;;---------------------------- Theme config code 

;;-- Get the recoloring code
(require 'sawfish.wm.util.recolor-image)

;;-- Start a configuration theme
(defgroup LiquidMetal "LiquidMetal Theme"
  :group appearance)

;;-- Font colors
(defcustom LiquidMetal:font-color-focused "white"
  "Font color for your focused title bar."
  :type (color)
  :group (appearance LiquidMetal)
  :user-level novice
  :after-set after-setting-frame-option
)

(defcustom LiquidMetal:font-color-unfocused "white"
  "Font color for your unfocused title bars."
  :type (color)
  :group (appearance LiquidMetal)
  :user-level novice
  :after-set after-setting-frame-option
)

;;-- Bar colors
(defcustom LiquidMetal:bar-color-focused "white"
  "Color for focused window pattern"
  :type (color)
  :group (appearance LiquidMetal)
  :user-level novice
  :after-set (lambda () (color-changed))
)

(defcustom LiquidMetal:bar-color-unfocused "white"
  "Color for unfocused window pattern"
  :type (color)
  :group (appearance LiquidMetal)
  :user-level novice
  :after-set (lambda () (color-changed))
)

;;-- Pattern choosers
(defcustom LiquidMetal:theme-pattern-focused 'brushedMetal
  "Your focused window pattern: \\w"
  :type (choice 
    (asteroid "Asteroid")
    (bakedMud "Baked Mud")
    (brightVeins "Bright Veins")
    (brushedMetal "Brushed Metal")
    (bumps "Bumps")
    (bush "Bushes")
    (castle "Castle")
    (cheetah "Cheetah")
    (crackedStones "Cracked Stones")
    (crunchy "Crunchy")
    (curvedGrain "Curved Grain")
    (danger "Danger!")
    (darkVeins "Dark Veins")
    (dunes "Dunes")
    (escher "Escher")
    (floorBoards "Floor Boards")
    (fog "Fog")
    (gnuBert "GNU-Bert")
    (gravel "Gravel")
    (jagged "Jagged")
    (leopard "Leopard")
    (lightning "Lightning")
    (lips "Lips")
    (lunar "Lunar")
    (marble  "Marble")
    (muddyLeaves "Muddy Leaves")
    (oilAndWater "Oil And Water")
    (oldstone "Old Stones")
    (pathStones "Path Stones")
    (plants "Plants")
    (rainyPuddle "Rainy Puddle")
    (rolledLeaves "Rolled Leaves")
    (smoke "Smoke")
    (stampedMetal "Stamped Metal")
    (stone "Stone")
    (stormy "Stormy")
    (subtle "Sublte")
    (weeds "Weeds")
    (wideGrain "Wide Grain")
    (windyWaves "Windy Waves")
    (woodPaneling "Wood Panels")
    (solid "Solid")
  )
  :group (appearance LiquidMetal)
  :after-set (lambda () (color-changed))
)

(defcustom LiquidMetal:theme-pattern-unfocused 'curvedGrain-dark
  "Your unfocused window pattern: \\w"
  :type (choice 
    (asteroid-dark "Asteroid")
    (bakedMud-dark "Baked Mud")
    (brightVeins-dark "Bright Veins")
    (brushedMetal-dark "Brushed Metal")
    (bumps-dark "Bumps")
    (bush-dark "Bushes")
    (castle-dark "Castle")
    (cheetah-dark "Cheetah")
    (crackedStones-dark "Cracked Stones")
    (crunchy-dark "Crunchy")
    (curvedGrain-dark "Curved Grain")
    (danger-dark "Danger!")
    (darkVeins-dark "Dark Veins")
    (dunes-dark "Dunes")
    (escher-dark "Escher")
    (floorBoards-dark "Floor Boards")
    (fog-dark "Fog")
    (gnuBert-dark "GNU-Bert")
    (gravel-dark "Gravel")
    (jagged-dark "Jagged")
    (leopard-dark "Leopard")
    (lightning-dark "Lightning")
    (lips-dark "Lips")
    (lunar-dark "Lunar")
    (marble-dark  "Marble")
    (muddyLeaves-dark "Muddy Leaves")
    (oilAndWater-dark "Oil And Water")
    (oldstone-dark "Old Stones")
    (pathStones-dark "Path Stones")
    (plants-dark "Plants")
    (rainyPuddle-dark "Rainy Puddle")
    (rolledLeaves-dark "Rolled Leaves")
    (smoke-dark "Smoke")
    (stampedMetal-dark "Stamped Metal")
    (stone-dark "Stone")
    (stormy-dark "Stormy")
    (subtle-dark "Sublte")
    (weeds-dark "Weeds")
    (wideGrain-dark "Wide Grain")
    (windyWaves-dark "Windy Waves")
    (woodPaneling-dark "Wood Panels")
    (solid-dark "Solid")
  )
  :group (appearance LiquidMetal)
  :after-set (lambda () (color-changed))
)


;;-- GTK support
(define initialize-gtkrc
  (let ((done nil))
    (lambda ()
      (unless done
	(require 'gtkrc)
	;; recolour everything when the GTK theme changes
	(gtkrc-call-after-changed color-changed)
	(setq done t)))))

;;---- Support for re-framing after a user config change (Crux)
(define (rebuild-all)
  (rebuild-frames-with-style 'LiquidMetal))

(define (reframe-all)
  (reframe-windows-with-style 'LiquidMetal))

(define (color-changed)
  (recolor-all)
  (reframe-all)
  (rebuild-all)
)


;;----- Methods for getting the proper colors (selected or GTK) (Crux)
(define (focused-color)
  (if (colorp LiquidMetal:bar-color-focused)
      LiquidMetal:bar-color-focused
      (initialize-gtkrc)
      (if (colorp (nth 3 gtkrc-background))
	  (nth 3 gtkrc-background)
          (get-color "steelblue")
      )
  )
)

(define (unfocused-color)
  (if (colorp LiquidMetal:bar-color-unfocused)
      LiquidMetal:bar-color-unfocused
      (initialize-gtkrc)
      (if (colorp (nth 3 gtkrc-background))
	  (nth 3 gtkrc-background)
          (get-color "steelblue")
      )
  )
)


;;------ Extra button definitions
(def-frame-class shade-button '((cursor . left_ptr))
  (bind-keys shade-button-keymap "Button1-Off" 'toggle-window-shaded)
)

(def-frame-class sticky-button '((cursor . left_ptr))
  (bind-keys sticky-button-keymap "Button1-Off" 'toggle-window-sticky)
)

;;----- Translates selections into images
(defun fileName (x)
  (cond
    ((equal x 'asteroid-dark)      asteroid-dark-png)
    ((equal x 'bakedMud-dark)      bakedMud-dark-png)
    ((equal x 'brightVeins-dark)   brightVeins-dark-png)
    ((equal x 'brushedMetal-dark)  brushedMetal-dark-png)
    ((equal x 'bumps-dark)         bumps-dark-png)
    ((equal x 'bush-dark)          bush-dark-png)
    ((equal x 'castle-dark)        castle-dark-png)
    ((equal x 'cheetah-dark)       cheetah-dark-png)
    ((equal x 'crackedStones-dark) crackedStones-dark-png)
    ((equal x 'crunchy-dark)       crunchy-dark-png)
    ((equal x 'curvedGrain-dark)   curvedGrain-dark-png)
    ((equal x 'danger-dark)        danger-dark-png)
    ((equal x 'darkVeins-dark)     darkVeins-dark-png)
    ((equal x 'dunes-dark)         dunes-dark-png)
    ((equal x 'escher-dark)        escher-dark-png)
    ((equal x 'floorBoards-dark)   floorBoards-dark-png)
    ((equal x 'fog-dark)           fog-dark-png)
    ((equal x 'gnuBert-dark)       gnuBert-dark-png)
    ((equal x 'gravel-dark)        gravel-dark-png)
    ((equal x 'jagged-dark)        jagged-dark-png)
    ((equal x 'leopard-dark)       leopard-dark-png)
    ((equal x 'lightning-dark)     lightning-dark-png)
    ((equal x 'lips-dark)          lips-dark-png)
    ((equal x 'lunar-dark)         lunar-dark-png)
    ((equal x 'marble-dark)        marble-dark-png)
    ((equal x 'muddyLeaves-dark)   muddyLeaves-dark-png)
    ((equal x 'oilAndWater-dark)   oilAndWater-dark-png)
    ((equal x 'oldstone-dark)      oldstone-dark-png)
    ((equal x 'pathStones-dark)    pathStones-dark-png)
    ((equal x 'plants-dark)        plants-dark-png)
    ((equal x 'rainyPuddle-dark)   rainyPuddle-dark-png)
    ((equal x 'rolledLeaves-dark)  rolledLeaves-dark-png)
    ((equal x 'smoke-dark)         smoke-dark-png)
    ((equal x 'stampedMetal-dark)  stampedMetal-dark-png)
    ((equal x 'stone-dark)         stone-dark-png)
    ((equal x 'stormy-dark)        stormy-dark-png)
    ((equal x 'subtle-dark)        subtle-dark-png)
    ((equal x 'weeds-dark)         weeds-dark-png)
    ((equal x 'wideGrain-dark)     wideGrain-dark-png)
    ((equal x 'windyWaves-dark)    windyWaves-dark-png)
    ((equal x 'woodPaneling-dark)  woodPaneling-dark-png)
    ((equal x 'solid-dark)         solid-dark-png)
    ((equal x 'asteroid)           asteroid-png)
    ((equal x 'bakedMud)           bakedMud-png)
    ((equal x 'brightVeins)        brightVeins-png)
    ((equal x 'brushedMetal)       brushedMetal-png)
    ((equal x 'bumps)              bumps-png)
    ((equal x 'bush)               bush-png)
    ((equal x 'castle)             castle-png)
    ((equal x 'cheetah)            cheetah-png)
    ((equal x 'crackedStones)      crackedStones-png)
    ((equal x 'crunchy)            crunchy-png)
    ((equal x 'curvedGrain)        curvedGrain-png)
    ((equal x 'danger)             danger-png)
    ((equal x 'darkVeins)          darkVeins-png)
    ((equal x 'dunes)              dunes-png)
    ((equal x 'escher)             escher-png)
    ((equal x 'floorBoards)        floorBoards-png)
    ((equal x 'fog)                fog-png)
    ((equal x 'gnuBert)            gnuBert-png)
    ((equal x 'gravel)             gravel-png)
    ((equal x 'jagged)             jagged-png)
    ((equal x 'leopard)            leopard-png)
    ((equal x 'lightning)          lightning-png)
    ((equal x 'lips)               lips-png)
    ((equal x 'lunar)              lunar-png)
    ((equal x 'marble)             marble-png)
    ((equal x 'muddyLeaves)        muddyLeaves-png)
    ((equal x 'oilAndWater)        oilAndWater-png)
    ((equal x 'oldstone)           oldstone-png)
    ((equal x 'pathStones)         pathStones-png)
    ((equal x 'plants)             plants-png)
    ((equal x 'rainyPuddle)        rainyPuddle-png)
    ((equal x 'rolledLeaves)       rolledLeaves-png)
    ((equal x 'smoke)              smoke-png)
    ((equal x 'stampedMetal)       stampedMetal-png)
    ((equal x 'stone)              stone-png)
    ((equal x 'stormy)             stormy-png)
    ((equal x 'subtle)             subtle-png)
    ((equal x 'weeds)              weeds-png)
    ((equal x 'wideGrain)          wideGrain-png)
    ((equal x 'windyWaves)         windyWaves-png)
    ((equal x 'woodPaneling)       woodPaneling-png)
    ((equal x 'solid)              solid-png)
    ((equal 5 5)                   fog-png)
  )
)


;;---------- Define button graphics
(define maxBtn 
   (list    (make-image "part#8.png") 
            (make-image "part#8.png") 
            (make-image "part#8.png") 
            (make-image "part#8-clicked.png")
   )
)

(define closeBtn 
   (list  (make-image "part#9.png") 
          (make-image "part#9.png")
          (make-image "part#9.png")
          (make-image "part#9-clicked.png")
   )
)

(define minBtn 
   (list  (make-image "part#7.png") 
          (make-image "part#7.png")
          (make-image "part#7.png")
          (make-image "part#7-clicked.png")
   )
)

(define shadeBtn 
   (list  (make-image "part#Shade.png") 
          (make-image "part#Shade.png")
          (make-image "part#Shade.png")
          (make-image "part#Shade-clicked.png")
   )
)

(define stickBtn 
   (list  (make-image "part#Sticky.png") 
          (make-image "part#Sticky.png")
          (make-image "part#Sticky.png")
          (make-image "part#Sticky-clicked.png")
   )
)

(define menuBtn  
   (list (make-image "part#5.png") 
         (make-image "part#5.png") 
         (make-image "part#5.png") 
         (make-image "part#5.png")
   )
)

(define mainTitle 
   (list (make-image "fog.png") 
         (make-image "fog.png") 
         (make-image "fog.png") 
         (make-image "fog.png")
   )
)


;;-------- Returns menu graphics based on selections
(defun getMenu () 
   (list 
     (fileName LiquidMetal:theme-pattern-unfocused)
     (fileName LiquidMetal:theme-pattern-focused)
     (fileName LiquidMetal:theme-pattern-unfocused)
     (fileName LiquidMetal:theme-pattern-focused)
   )
)


;;-------- Recolors the selected images (hacked out of Crux)
(define (recolor-all)
  ;; Use the SELECTED state of the background colors as the
  ;; midpoint of the gradient for recolouring images. (This is
  ;; usually a bright, contrasting colour, and thus is the
  ;; best choice. It works particularly well with the Eazel-Foo
  ;; themes)
  (let ((recolorer (make-image-recolorer 
                    (focused-color)
		    #:zero-channel blue-channel
			#:index-channel green-channel
                   )
         )
       )
       (mapc (lambda (x) (mapc recolorer x) ) 
          (list (list
            (fileName LiquidMetal:theme-pattern-focused)
          ))
        )
    )
   (let ((recolorer (make-image-recolorer 
                    (unfocused-color)
		    #:zero-channel blue-channel
			#:index-channel green-channel
                   )
         )
       )
       (mapc (lambda (x) (mapc recolorer x) ) 
          (list (list
            (fileName LiquidMetal:theme-pattern-unfocused)
        )))
    )
)


;;------ Loads all of the images.  
;;       (Tried really hard to only load the images being used, but doing
;;        so causes an error when user makes a config change.  If sawfish
;;        is fixed, I'll update the code.  Until then the images are loaded,
;;        swapped to disk and the ignored until needed)
(define asteroid-dark-png (make-image "asteroid-dark.png"))
(define bakedMud-dark-png (make-image "bakedMud-dark.png"))
(define brightVeins-dark-png (make-image "brightVeins-dark.png"))
(define brushedMetal-dark-png (make-image "brushedMetal-dark.png"))
(define bumps-dark-png (make-image "bumps-dark.png"))
(define bush-dark-png (make-image "bush-dark.png"))
(define castle-dark-png (make-image "castle-dark.png"))
(define cheetah-dark-png (make-image "cheetah-dark.png"))
(define crackedStones-dark-png (make-image "crackedStones-dark.png"))
(define crunchy-dark-png (make-image "crunchy-dark.png"))
(define curvedGrain-dark-png (make-image "curvedGrain-dark.png"))
(define danger-dark-png (make-image  "danger-dark.png"))
(define darkVeins-dark-png (make-image  "darkVeins-dark.png"))
(define dunes-dark-png (make-image  "dunes-dark.png"))
(define escher-dark-png (make-image  "escher-dark.png"))
(define floorBoards-dark-png (make-image "floorBoards-dark.png"))
(define fog-dark-png (make-image "fog-dark.png"))
(define gnuBert-dark-png (make-image "gnuBert-dark.png"))
(define gravel-dark-png (make-image "gravel-dark.png"))
(define jagged-dark-png (make-image "jagged-dark.png"))
(define leopard-dark-png (make-image "leopard-dark.png"))
(define lightning-dark-png (make-image "lightning-dark.png"))
(define lips-dark-png (make-image "lips-dark.png"))
(define lunar-dark-png (make-image "lunar-dark.png"))
(define marble-dark-png (make-image  "marble-dark.png"))
(define muddyLeaves-dark-png (make-image "muddyLeaves-dark.png"))
(define oilAndWater-dark-png (make-image "oilAndWater-dark.png"))
(define oldstone-dark-png (make-image "oldstone-dark.png"))
(define pathStones-dark-png (make-image "pathStones-dark.png"))
(define plants-dark-png (make-image "plants-dark.png"))
(define rainyPuddle-dark-png (make-image "rainyPuddle-dark.png"))
(define rolledLeaves-dark-png (make-image "rolledLeaves-dark.png"))
(define smoke-dark-png (make-image "smoke-dark.png"))
(define stampedMetal-dark-png (make-image "stampedMetal-dark.png"))
(define stone-dark-png (make-image "stone-dark.png"))
(define stormy-dark-png (make-image "stormy-dark.png"))
(define subtle-dark-png (make-image "subtle-dark.png"))
(define weeds-dark-png (make-image "weeds-dark.png"))
(define wideGrain-dark-png (make-image "wideGrain-dark.png"))
(define windyWaves-dark-png (make-image "windyWaves-dark.png"))
(define woodPaneling-dark-png (make-image "woodPaneling-dark.png"))
(define solid-dark-png (make-image "solid-dark.png"))
(define asteroid-png (make-image "asteroid.png"))
(define bakedMud-png (make-image "bakedMud.png"))
(define brightVeins-png (make-image "brightVeins.png"))
(define brushedMetal-png (make-image "brushedMetal.png"))
(define bumps-png (make-image "bumps.png"))
(define bush-png (make-image "bush.png"))
(define castle-png (make-image "castle.png"))
(define cheetah-png (make-image "cheetah.png"))
(define crackedStones-png (make-image "crackedStones.png"))
(define crunchy-png (make-image "crunchy.png"))
(define curvedGrain-png (make-image "curvedGrain.png"))
(define danger-png (make-image "danger.png"))
(define darkVeins-png (make-image "darkVeins.png"))
(define dunes-png (make-image "dunes.png"))
(define escher-png (make-image "escher.png"))
(define floorBoards-png (make-image "floorBoards.png"))
(define fog-png (make-image "fog.png"))
(define gnuBert-png (make-image "gnuBert.png"))
(define gravel-png (make-image "gravel.png"))
(define jagged-png (make-image "jagged.png"))
(define leopard-png (make-image "leopard.png"))
(define lightning-png (make-image "lightning.png"))
(define lips-png (make-image "lips.png"))
(define lunar-png (make-image "lunar.png"))
(define marble-png (make-image  "marble.png"))
(define muddyLeaves-png (make-image "muddyLeaves.png"))
(define oilAndWater-png (make-image "oilAndWater.png"))
(define oldstone-png (make-image "oldstone.png"))
(define pathStones-png (make-image "pathStones.png"))
(define plants-png (make-image "plants.png"))
(define rainyPuddle-png (make-image "rainyPuddle.png"))
(define rolledLeaves-png (make-image "rolledLeaves.png"))
(define smoke-png (make-image "smoke.png"))
(define stampedMetal-png (make-image "stampedMetal.png"))
(define stone-png (make-image "stone.png"))
(define stormy-png (make-image "stormy.png"))
(define subtle-png (make-image "subtle.png"))
(define weeds-png (make-image "weeds.png"))
(define wideGrain-png (make-image "wideGrain.png"))
(define windyWaves-png (make-image "windyWaves.png"))
(define woodPaneling-png (make-image "woodPaneling.png"))
(define solid-png (make-image "solid.png"))


;;-----------------------------------Start the main configuration section
(let* (

     ;;--- Select the correct font color
     (font-colors (lambda (w)
		     (list (or (window-get w 'frame-inactive-color)
			       LiquidMetal:font-color-unfocused)
			   (or (window-get w 'frame-active-color)
			       LiquidMetal:font-color-focused)))
     )

     ;;--- Define the main focused window frame (All these from simple)
     (frame `(
         ((foreground . ,font-colors)
          (top-edge . -21)
          (right-edge . 0)
          (left-edge . 0)
          (text . ,window-name)
          (background . ,getMenu )
          (class . title)
          (x-justify . center)
          (y-justify . center))
         ((right-edge . -4)
          (background . ,(make-image "part#18.png") )
          (top-edge . 0)
          (bottom-edge . 0)
          (class . right-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#17.png") )
          (right-edge . -4)
          (bottom-edge . -4)
          (class . bottom-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#16.png"))
          (left-edge . 0)
          (right-edge . 0)
          (bottom-edge . -4)
          (class . bottom-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#15.png"))
          (left-edge . -4)
          (bottom-edge . -4)
          (class . bottom-left-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#14.png"))
          (left-edge . -4)
          (top-edge . 0)
          (bottom-edge . 0)
          (class . left-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#13.png"))
          (right-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#12.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#11.png"))
          (left-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#10.png"))
          (right-edge . -4)
          (top-edge . -21)
          (class . top-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,closeBtn)
          (right-edge . 0)
          (top-edge . -21)
          (class . close-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,maxBtn)
          (right-edge . 19)
          (top-edge . -21)
          (class . maximize-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,minBtn)
          (right-edge . 33)
          (top-edge . -21)
          (class . iconify-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,shadeBtn)
          (right-edge . 47)
          (top-edge . -21)
          (class . shade-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,stickBtn)
          (right-edge . 61)
          (top-edge . -21)
          (class . sticky-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,menuBtn)
          (left-edge . 0)
          (top-edge . -21)
          (class . menu-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#4.png"))
          (left-edge . -4)
          (top-edge . -21)
          (class . top-left-corner))
         ((background . ,(make-image "part#3.png"))
          (right-edge . -4)
          (top-edge . -26)
          (class . top-right-corner))
         ((background . ,(make-image "part#2.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -26)
          (class . top-border))
        ((background . ,(make-image "part.png"))
          (left-edge . -4)
          (top-edge . -26)
          (class . none)) 
     ))

     ;;------ Define the shaded window frame
     (shaped-frame `(
         ((foreground . ,font-colors)
          (top-edge . -21)
          (right-edge . 0)
          (left-edge . 0)
          (text . ,window-name)
          (background . ,getMenu )
          (class . title)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#13.png"))
          (right-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#12.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#11.png"))
          (left-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#10.png"))
          (right-edge . -4)
          (top-edge . -21)
          (class . top-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,closeBtn)
          (right-edge . 0)
          (top-edge . -21)
          (class . close-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,maxBtn)
          (right-edge . 19)
          (top-edge . -21)
          (class . maximize-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,minBtn)
          (right-edge . 33)
          (top-edge . -21)
          (class . iconify-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,shadeBtn)
          (right-edge . 47)
          (top-edge . -21)
          (class . shade-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,stickBtn)
          (right-edge . 61)
          (top-edge . -21)
          (class . sticky-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,menuBtn)
          (left-edge . 0)
          (top-edge . -21)
          (class . menu-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#4.png"))
          (left-edge . -4)
          (top-edge . -21)
          (class . top-left-corner))
         ((background . ,(make-image "part#3.png"))
          (right-edge . -4)
          (top-edge . -26)
          (class . top-right-corner))
         ((background . ,(make-image "part#2.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -26)
          (class . top-border))
         ((background . ,(make-image "part.png"))
          (left-edge . -4)
          (top-edge . -26)
          (class . none)) 
     ))

     ;;------ Transient frame definition
     (transient-frame `(
         ((foreground . ,font-colors)
          (top-edge . -21)
          (right-edge . 0)
          (left-edge . 0)
          (text . ,window-name)
          (background . ,getMenu )
          (class . title)
          (x-justify . center)
          (y-justify . center))
         ((right-edge . -4)
          (background . ,(make-image "part#18.png") )
          (top-edge . 0)
          (bottom-edge . 0)
          (class . right-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#17.png") )
          (right-edge . -4)
          (bottom-edge . -4)
          (class . bottom-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#16.png"))
          (left-edge . 0)
          (right-edge . 0)
          (bottom-edge . -4)
          (class . bottom-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#15.png"))
          (left-edge . -4)
          (bottom-edge . -4)
          (class . bottom-left-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#14.png"))
          (left-edge . -4)
          (top-edge . 0)
          (bottom-edge . 0)
          (class . left-border)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#13.png"))
          (right-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#12.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#11.png"))
          (left-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#10.png"))
          (right-edge . -4)
          (top-edge . -21)
          (class . top-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,closeBtn)
          (right-edge . 0)
          (top-edge . -21)
          (class . close-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,maxBtn)
          (right-edge . 19)
          (top-edge . -21)
          (class . maximize-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,minBtn)
          (right-edge . 33)
          (top-edge . -21)
          (class . iconify-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,shadeBtn)
          (right-edge . 47)
          (top-edge . -21)
          (class . shade-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,stickBtn)
          (right-edge . 61)
          (top-edge . -21)
          (class . sticky-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,menuBtn)
          (left-edge . 0)
          (top-edge . -21)
          (class . menu-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#4.png"))
          (left-edge . -4)
          (top-edge . -21)
          (class . top-left-corner))
         ((background . ,(make-image "part#3.png"))
          (right-edge . -4)
          (top-edge . -26)
          (class . top-right-corner))
         ((background . ,(make-image "part#2.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -26)
          (class . top-border))
         ((background . ,(make-image "part.png"))
          (left-edge . -4)
          (top-edge . -26)
          (class . none))
     ))

     ;;---- shaded transient frames.
     (shaped-transient-frame `(
         ((foreground . ,font-colors)
          (top-edge . -21)
          (right-edge . 0)
          (left-edge . 0)
          (text . ,window-name)
          (background . ,getMenu )
          (class . title)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#13.png"))
          (right-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#12.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#11.png"))
          (left-edge . -4)
          (top-edge . -4)
          (class . none)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#10.png"))
          (right-edge . -4)
          (top-edge . -21)
          (class . top-right-corner)
          (x-justify . center)
          (y-justify . center))
         ((background . ,closeBtn)
          (right-edge . 0)
          (top-edge . -21)
          (class . close-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,maxBtn)
          (right-edge . 19)
          (top-edge . -21)
          (class . maximize-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,minBtn)
          (right-edge . 33)
          (top-edge . -21)
          (class . iconify-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,shadeBtn)
          (right-edge . 47)
          (top-edge . -21)
          (class . shade-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,stickBtn)
          (right-edge . 61)
          (top-edge . -21)
          (class . sticky-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,menuBtn)
          (left-edge . 0)
          (top-edge . -21)
          (class . menu-button)
          (x-justify . center)
          (y-justify . center))
         ((background . ,(make-image "part#4.png"))
          (left-edge . -4)
          (top-edge . -21)
          (class . top-left-corner))
         ((background . ,(make-image "part#3.png"))
          (right-edge . -4)
          (top-edge . -26)
          (class . top-right-corner))
         ((background . ,(make-image "part#2.png"))
          (left-edge . 18)
          (right-edge . 19)
          (top-edge . -26)
          (class . top-border))
         ((background . ,(make-image "part.png"))
          (left-edge . -4)
          (top-edge . -26)
          (class . none))
       )) 
  
  )

  ;;------ setup the initial colours
  (recolor-all)


  ;;------ Apply this style to the windows
  (add-frame-style 'LiquidMetal
		   (lambda (w type)
		     (case type
		       ((default) frame)
		       ((transient) transient-frame)
		       ((shaped) shaped-frame)
		       ((shaped-transient) shaped-transient-frame)
                     )
                    )
   )
)

;;---- recalibrate frames when the window-name changes (Crux)
(call-after-property-changed 'WM_NAME rebuild-frame)
